@@ -1,4 +1,8 @@
 AGENT = 'agent'     # Generic use.  "Who is responsible for this event?"
+FIELDS = 'fields'   # A list of fields that may be of interest.  For instance,
+                    # fas uses this to specify which fields were updated in
+                    # a user.update event.
+
 USER = 'user'       # FAS
 TAG = 'tag'         # For fedora-tagger
 LOG = 'log'         # For fedmsg-logger
